@@ -11,6 +11,7 @@ import logging
 import os
 import re
 import shutil
+import site
 import subprocess  # noqa: S404
 import sys
 import warnings
@@ -24,7 +25,6 @@ from packaging.version import Version
 
 from ansible_compat.config import (
     AnsibleConfig,
-    ansible_collections_path,
     parse_ansible_version,
 )
 from ansible_compat.constants import (
@@ -195,6 +195,9 @@ class Runtime:
         self.isolated = isolated
         self.max_retries = max_retries
         self.environ = environ or os.environ.copy()
+        if "ANSIBLE_COLLECTIONS_PATHS" in self.environ:
+            msg = "ANSIBLE_COLLECTIONS_PATHS was detected, replace it with ANSIBLE_COLLECTIONS_PATH to continue."
+            raise RuntimeError(msg)
         self.plugins = Plugins(runtime=self)
         self.verbosity = verbosity
 
@@ -214,7 +217,7 @@ class Runtime:
         self.config = AnsibleConfig(cache_dir=self.cache_dir)
 
         # Add the sys.path to the collection paths if not isolated
-        self._add_sys_path_to_collection_paths()
+        self._patch_collection_paths()
 
         if not self.version_in_range(lower=min_required_version):
             msg = f"Found incompatible version of ansible runtime {self.version}, instead of {min_required_version} or newer."
@@ -259,17 +262,43 @@ class Runtime:
         # Use module-level _logger instance to validate it
         _logger.debug("Logging initialized to level %s", logging_level)
 
-    def _add_sys_path_to_collection_paths(self) -> None:
-        """Add the sys.path to the collection paths."""
+    def _patch_collection_paths(self) -> None:
+        """Modify Ansible collection path for testing purposes.
+
+        - Add the sys.path to the end of collection paths.
+        - Add the site-packages to the beginning of collection paths to match
+          ansible-core and ade behavior and trick ansible-galaxy to install
+          default to the venv site-packages location (isolation).
+        """
+        collections_paths: list[str] = self.config.collections_paths.copy()
         if self.config.collections_scan_sys_path:
             for path in sys.path:
                 if (
-                    path not in self.config.collections_paths
+                    path not in collections_paths
                     and (Path(path) / "ansible_collections").is_dir()
                 ):
-                    self.config.collections_paths.append(  # pylint: disable=E1101
+                    collections_paths.append(  # pylint: disable=E1101
                         path,
                     )
+            # When inside a venv, we also add the site-packages to the top of the
+            # collections path because this is the first place where ansible-core
+            # will look for them. This also ensures that when calling ansible-galaxy
+            # to install content, it will be installed in the venv site-packages instead
+            # of altering the user configuration. Matches behavior of ADE and
+            # ensures isolation.
+            for path in reversed(site.getsitepackages()):
+                if path not in collections_paths:
+                    collections_paths.insert(0, path)
+
+            if collections_paths != self.config.collections_paths:
+                _logger.info(
+                    "Collection paths was patch to include extra directories %s",
+                    ",".join(collections_paths),
+                )
+        else:
+            msg = "ANSIBLE_COLLECTIONS_SCAN_SYS_PATH is disabled, not patching collection paths. This may lead to unexpected behavior when using dev tools and prevent full isolation from user environment."
+            _logger.warning(msg)
+        self.config.collections_paths = collections_paths
 
     def load_collections(self) -> None:
         """Load collection data."""
@@ -505,7 +534,7 @@ class Runtime:
         cpaths: list[str] = self.config.collections_paths
         if destination and str(destination) not in cpaths:
             # we cannot use '-p' because it breaks galaxy ability to ignore already installed collections, so
-            # we hack ansible_collections_path instead and inject our own path there.
+            # we hack ANSIBLE_COLLECTIONS_PATH instead and inject our own path there.
             # pylint: disable=no-member
             cpaths.insert(0, str(destination))
         cmd.append(f"{collection}")
@@ -514,7 +543,7 @@ class Runtime:
         process = self.run(
             cmd,
             retry=True,
-            env={**self.environ, ansible_collections_path(): ":".join(cpaths)},
+            env={**self.environ, "ANSIBLE_COLLECTIONS_PATH": ":".join(cpaths)},
         )
         if process.returncode != 0:
             msg = f"Command {' '.join(cmd)}, returned {process.returncode} code:\n{process.stdout}\n{process.stderr}"
@@ -822,7 +851,7 @@ class Runtime:
         if library_paths != self.config.DEFAULT_MODULE_PATH:
             self._update_env("ANSIBLE_LIBRARY", library_paths)
         if collections_path != self.config.default_collections_path:
-            self._update_env(ansible_collections_path(), collections_path)
+            self._update_env("ANSIBLE_COLLECTIONS_PATH", collections_path)
         if roles_path != self.config.default_roles_path:
             self._update_env("ANSIBLE_ROLES_PATH", roles_path)
 
